@@ -26,6 +26,7 @@ using namespace std;
 ClientBoard::ClientBoard()
 : currentHand(0), pot(0), sets(0)
 {
+	myCards[0] = myCards[1] = myCards[2] = myCards[3] = myCards[4] = 0;
 }
 
 
@@ -118,6 +119,12 @@ ClientBoard::distributePot()
 
 }
 
+void
+ClientBoard::determinePlayerNeedToShowCards()
+{
+
+}
+
 std::list<unsigned>
 ClientBoard::getWinners() const
 {
@@ -132,3 +139,16 @@ ClientBoard::setWinners(const std::list<unsigned> &w)
 	winners = w;
 }
 
+std::list<unsigned>
+ClientBoard::getPlayerNeedToShowCards() const
+{
+	boost::recursive_mutex::scoped_lock lock(m_syncMutex);
+	return playerNeedToShowCards;
+}
+
+void
+ClientBoard::setPlayerNeedToShowCards(const std::list<unsigned> &p)
+{
+	boost::recursive_mutex::scoped_lock lock(m_syncMutex);
+	playerNeedToShowCards = p;
+}
