@@ -23,8 +23,16 @@ using namespace std;
 
 
 ClientPlayer::ClientPlayer(ConfigFile *c, BoardInterface *b, int id, unsigned uniqueId, PlayerType type, std::string name, std::string avatar, int sC, bool aS, int mB)
-: PlayerInterface(), myConfig(c), currentHand(0), currentBoard(b), myCardsValue(0), myID(id), myUniqueID(uniqueId), myType(type), myName(name), myAvatar(avatar), myDude(0), myDude4(0), myCardsValueInt(0), myOdds(-1.0), myCash(sC), mySet(0), myLastRelativeSet(0), myAction(0), myButton(mB), myActiveStatus(aS), myStayOnTableStatus(1), myTurn(0), myRoundStartCash(0), sBluff(0), sBluffStatus(0)
+: PlayerInterface(), myConfig(c), currentHand(0), currentBoard(b), myCardsValue(0), myID(id), myUniqueID(uniqueId), myType(type),
+  myName(name), myAvatar(avatar), myDude(0), myDude4(0), myCardsValueInt(0), myOdds(-1.0), myCash(sC), mySet(0), myLastRelativeSet(0),
+  myAction(0), myButton(mB), myActiveStatus(aS), myStayOnTableStatus(true), myTurn(false), myCardsFlip(false), myRoundStartCash(0),
+  lastMoneyWon(0), sBluff(0), sBluffStatus(false), myWinnerState(false)
 {
+	myBestHandPosition[0] = myBestHandPosition[1] = myBestHandPosition[2] = myBestHandPosition[3] = myBestHandPosition[4] = 0;
+	myNiveau[0] = myNiveau[1] = myNiveau[2] = 0;
+	myCards[0] = myCards[1] = 0;
+	myAverageSets[0] = myAverageSets[1] = myAverageSets[2] = myAverageSets[3] = 0;
+	myAggressive[0] = myAggressive[1] = myAggressive[2] = myAggressive[3] = myAggressive[4] = myAggressive[5] = myAggressive[6] = false;
 }
 
 
@@ -258,11 +266,11 @@ ClientPlayer::setMyCardsFlip(bool theValue, int state)
 	// log flipping cards
 	if (myCardsFlip) {
 		switch(state) {
-			case 1: currentHand->getGuiInterface()->logFlipHoleCardsMsg(myName, myCards[0], myCards[1], myCardsValueInt);
+                        case 1: currentHand->getGuiInterface()->logFlipHoleCardsMsg(myName, myID, myCards[0], myCards[1], myCardsValueInt);
 			break;
-			case 2: currentHand->getGuiInterface()->logFlipHoleCardsMsg(myName, myCards[0], myCards[1]);
+                        case 2: currentHand->getGuiInterface()->logFlipHoleCardsMsg(myName, myID, myCards[0], myCards[1]);
 			break;
-			case 3: currentHand->getGuiInterface()->logFlipHoleCardsMsg(myName, myCards[0], myCards[1], myCardsValueInt, "has");
+                        case 3: currentHand->getGuiInterface()->logFlipHoleCardsMsg(myName, myID, myCards[0], myCards[1], myCardsValueInt, "has");
 			break;
 			default: ;
 		}
@@ -515,3 +523,14 @@ boost::shared_ptr<SessionData> ClientPlayer::getNetSessionData()
 	return myNetSessionData;
 }
 
+bool ClientPlayer::checkIfINeedToShowCards()
+{
+	boost::recursive_mutex::scoped_lock lock(m_syncMutex);
+	std::list<unsigned> playerNeedToShowCardsList = currentBoard->getPlayerNeedToShowCards();
+    for(std::list<unsigned>::iterator it = playerNeedToShowCardsList.begin(); it != playerNeedToShowCardsList.end(); it++)
+    {
+        if(*it == myUniqueID) return true;
+    }
+
+    return false;
+}
