@@ -115,6 +115,12 @@ public:
 
 	virtual void setNetSessionData(boost::shared_ptr<SessionData> session) =0;
 	virtual boost::shared_ptr<SessionData> getNetSessionData() =0;
+
+	virtual unsigned getActionTimeoutCounter() const =0;
+	virtual void incrementActionTimeoutCounter() =0;
+	virtual void resetActionTimeoutCounter() =0;
+
+	virtual bool checkIfINeedToShowCards() =0;
 };
 
 #endif
