@@ -20,30 +20,27 @@
 #ifndef GAME_H
 #define GAME_H
 
-#include <boost/shared_ptr.hpp>
+#include <engine_defs.h>
 #include "gamedata.h"
 #include "playerdata.h"
 
 #include <third_party/boost/timers.hpp>
 
 class GuiInterface;
+class Log;
 class HandInterface;
-class PlayerInterface;
 class BoardInterface;
 class EngineFactory;
 struct GameData;
 struct StartData;
 
-typedef boost::shared_ptr<std::list<boost::shared_ptr<PlayerInterface> > > PlayerList;
-typedef std::list<boost::shared_ptr<PlayerInterface> >::iterator PlayerListIterator;
-typedef std::list<boost::shared_ptr<PlayerInterface> >::const_iterator PlayerListConstIterator;
 
 class Game {
 
 public:
-	Game(GuiInterface *gui, boost::shared_ptr<EngineFactory> factory,
+    Game(GuiInterface *gui, boost::shared_ptr<EngineFactory> factory,
 		const PlayerDataList &playerDataList, const GameData &gameData,
-		const StartData &startData, int gameId);
+		const StartData &startData, int gameId, Log *myLog);
 
 	~Game();
 
@@ -74,6 +71,8 @@ public:
 	void setCurrentHandID(int theValue) { currentHandID = theValue; }
 	int getCurrentHandID() const { return currentHandID; }
 
+	unsigned getDealerPosition() const { return dealerPosition; }
+
 	boost::shared_ptr<PlayerInterface> getPlayerByUniqueId(unsigned id);
 	boost::shared_ptr<PlayerInterface> getCurrentPlayer();
 
@@ -83,6 +82,7 @@ private:
 	boost::shared_ptr<EngineFactory> myFactory;
 
 	GuiInterface *myGui;
+    Log *myLog;
 	HandInterface *currentHand;
 	BoardInterface *currentBoard;
 
@@ -95,7 +95,6 @@ private:
 	int startCash;
 	int startSmallBlind;
 	int myGameID;
-	int guiPlayerNum;
 
 	// running variables
 	int currentSmallBlind;
