@@ -11,7 +11,7 @@
 //
 #include "sdlplayer.h"
 
-#if (defined _WIN32) || (defined __APPLE__)
+#if (defined __APPLE__)
 	#include <SDL.h>
 #else
 	#include <SDL/SDL.h>
@@ -22,8 +22,8 @@ using namespace std;
 SDLPlayer::SDLPlayer(ConfigFile *c)
 : soundData(NULL), currentChannel(0) , audioEnabled(0), myConfig(c)
 {
-	SDL_Init(SDL_INIT_AUDIO);
-	initAudio();
+        SDL_Init(SDL_INIT_AUDIO);
+        initAudio();
 
 	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
 }
