@@ -33,11 +33,14 @@ startNetworkGameDialogImpl::startNetworkGameDialogImpl(startWindowImpl *parent,
 #endif	
 	setupUi(this);
 
-	myChat = new ChatTools(lineEdit_ChatInput, myConfig, 1, textBrowser_ChatDisplay, treeWidget );
+        myChat = new ChatTools(lineEdit_ChatInput, myConfig, LAN_LOBBY_CHAT, textBrowser_ChatDisplay);
 
 	lineEdit_ChatInput->installEventFilter(this);
 
-	connect( pushButton_cancel, SIGNAL( clicked() ), this, SLOT( cancel() ) );
+	//--- GUI_800x480 ---
+	//---
+	// connect( pushButton_cancel, SIGNAL( clicked() ), this, SLOT( cancel() ) );
+	//---
 	connect( pushButton_startGame, SIGNAL( clicked() ), this, SLOT( startGame() ) );
 	connect( pushButton_Kick, SIGNAL( clicked() ), this, SLOT( kickPlayer() ) );
 	connect( treeWidget, SIGNAL( currentItemChanged ( QTreeWidgetItem*, QTreeWidgetItem*) ), this, SLOT( playerSelected(QTreeWidgetItem*, QTreeWidgetItem*) ) );
@@ -70,14 +73,14 @@ void startNetworkGameDialogImpl::refresh(int actionID) {
 	}
 }
 
-void startNetworkGameDialogImpl::joinedNetworkGame(unsigned playerId, QString playerName, int rights) {
+void startNetworkGameDialogImpl::joinedNetworkGame(unsigned playerId, QString playerName, bool admin) {
 
 	myPlayerId = playerId;
-	isAdmin = rights == PLAYER_RIGHTS_ADMIN;
-	addConnectedPlayer(playerId, playerName, rights);
+        isAdmin = admin;
+        addConnectedPlayer(playerId, playerName, admin);
 }
 
-void startNetworkGameDialogImpl::addConnectedPlayer(unsigned playerId, QString playerName, int /*rights*/) {
+void startNetworkGameDialogImpl::addConnectedPlayer(unsigned playerId, QString playerName, bool) {
 
 	// TODO mark admin
 	QTreeWidgetItem *item = new QTreeWidgetItem(treeWidget, 0);
@@ -232,10 +235,6 @@ bool startNetworkGameDialogImpl::eventFilter(QObject *obj, QEvent *event)
 	}
 }
 
-void startNetworkGameDialogImpl::receiveChatMsg(QString playerName, QString message) {
-	myChat->receiveMessage(playerName, message);
-}
-
 void startNetworkGameDialogImpl::accept()
 {
 	myW->show();
