@@ -41,7 +41,9 @@ class ClientSenderCallback;
 class Game;
 class NetPacket;
 class AvatarManager;
+class Log;
 class QtToolsInterface;
+struct Gsasl;
 
 class ClientThread : public Thread, public boost::enable_shared_from_this<ClientThread>
 {
@@ -60,7 +62,6 @@ public:
 		bool ipv6,
 		bool sctp,
 		const std::string &avatarServerAddress,
-		const std::string &pwd,
 		const std::string &playerName,
 		const std::string &avatarFile,
 		const std::string &cacheDir);
@@ -70,25 +71,36 @@ public:
 	void SendLeaveCurrentGame();
 	void SendStartEvent(bool fillUpWithCpuPlayers);
 	void SendPlayerAction();
-	void SendChatMessage(const std::string &msg);
+	void SendGameChatMessage(const std::string &msg);
+	void SendLobbyChatMessage(const std::string &msg);
+	void SendPrivateChatMessage(unsigned targetPlayerId, const std::string &msg);
 	void SendJoinFirstGame(const std::string &password);
 	void SendJoinGame(unsigned gameId, const std::string &password);
 	void SendCreateGame(const GameData &gameData, const std::string &name, const std::string &password);
 	void SendResetTimeout();
 	void SendAskKickPlayer(unsigned playerId);
 	void SendVoteKick(bool doKick);
+	void SendShowMyCards();
+	void SendInvitePlayerToCurrentGame(unsigned playerId);
+	void SendRejectGameInvitation(unsigned gameId, DenyGameInvitationReason reason);
+	void SendReportAvatar(unsigned reportedPlayerId, const std::string &avatarHash);
 
 	void StartAsyncRead();
 	void HandleRead(const boost::system::error_code& ec, size_t bytesRead);
 
 	void SelectServer(unsigned serverId);
+	void SetLogin(const std::string &userName, const std::string &password, bool isGuest);
 	ServerInfo GetServerInfo(unsigned serverId) const;
 
 	GameInfo GetGameInfo(unsigned gameId) const;
 	PlayerInfo GetPlayerInfo(unsigned playerId) const;
 	bool GetPlayerIdFromName(const std::string &playerName, unsigned &playerId) const;
+	unsigned GetGameIdOfPlayer(unsigned playerId) const;
 	ServerStats GetStatData() const;
 	unsigned GetGameId() const;
+	unsigned GetGuiPlayerId() const;
+
+	Gsasl *GetAuthContext();
 
 	ClientCallback &GetCallback();
 	GuiInterface &GetGui();
@@ -98,13 +110,23 @@ protected:
 	typedef std::map<unsigned, GameInfo> GameInfoMap;
 	typedef std::list<boost::shared_ptr<NetPacket> > NetPacketList;
 	typedef std::map<unsigned, PlayerInfo> PlayerInfoMap;
-	typedef std::map<unsigned, boost::shared_ptr<AvatarData> > AvatarDataMap;
+	typedef std::map<unsigned, boost::shared_ptr<AvatarFile> > AvatarFileMap;
 	typedef std::map<unsigned, ServerInfo> ServerInfoMap;
+	struct LoginData
+	{
+		LoginData() : isGuest(false) {}
+		std::string userName;
+		std::string password;
+		bool isGuest;
+	};
 
 	// Main function of the thread.
 	virtual void Main();
 	void RegisterTimers();
 	void CancelTimers();
+
+	void InitAuthContext();
+	void ClearAuthContext();
 	void InitGame();
 
 	void SendSessionPacket(boost::shared_ptr<NetPacket> packet);
@@ -117,10 +139,10 @@ protected:
 	void SetNewGameAdmin(unsigned id);
 	void RetrieveAvatarIfNeeded(unsigned id, const PlayerInfo &info);
 
-	void AddTempAvatarData(unsigned playerId, unsigned avatarSize, AvatarFileType type);
-	void StoreInTempAvatarData(unsigned playerId, const std::vector<unsigned char> &data);
-	void CompleteTempAvatarData(unsigned playerId);
-	void PassAvatarDataToManager(unsigned playerId, boost::shared_ptr<AvatarData> avatarData);
+	void AddTempAvatarFile(unsigned playerId, unsigned avatarSize, AvatarFileType type);
+	void StoreInTempAvatarFile(unsigned playerId, const std::vector<unsigned char> &data);
+	void CompleteTempAvatarFile(unsigned playerId);
+	void PassAvatarFileToManager(unsigned playerId, boost::shared_ptr<AvatarFile> AvatarFile);
 	void SetUnknownAvatar(unsigned playerId);
 
 	void TimerCheckAvatarDownloads(const boost::system::error_code& ec);
@@ -144,7 +166,6 @@ protected:
 	void SetGameData(const GameData &gameData);
 	const StartData &GetStartData() const;
 	void SetStartData(const StartData &startData);
-	unsigned GetGuiPlayerId() const;
 	void SetGuiPlayerId(unsigned guiPlayerId);
 
 	boost::shared_ptr<Game> GetGame();
@@ -168,6 +189,8 @@ protected:
 	bool GetSelectedServer(unsigned &serverId) const;
 	void UseServer(unsigned serverId);
 
+	bool GetLoginData(LoginData &loginData) const;
+
 	unsigned GetGameIdByName(const std::string &name) const;
 	void AddGameInfo(unsigned gameId, const GameInfo &info);
 	void UpdateGameInfoMode(unsigned gameId, GameMode mode);
@@ -192,6 +215,9 @@ private:
 
 	boost::shared_ptr<boost::asio::io_service> m_ioService;
 	boost::shared_ptr<ClientSenderCallback> m_senderCallback;
+	boost::shared_ptr<Log> m_clientLog;
+
+	Gsasl *m_authContext;
 
 	NetPacketList m_outPacketList;
 
@@ -216,6 +242,9 @@ private:
 	unsigned m_selectedServerId;
 	mutable boost::mutex m_selectServerMutex;
 
+	LoginData m_loginData;
+	mutable boost::mutex m_loginDataMutex;
+
 	GameInfoMap m_gameInfoMap;
 	mutable boost::mutex m_gameInfoMapMutex;
 
@@ -234,10 +263,11 @@ private:
 	unsigned m_curPetitionId;
 	mutable boost::mutex m_curPetitionIdMutex;
 
-	AvatarDataMap m_tempAvatarMap;
+	AvatarFileMap m_tempAvatarMap;
 
 	unsigned m_curGameNum;
 	unsigned m_guiPlayerId;
+	mutable boost::mutex m_guiPlayerIdMutex;
 	bool m_sessionEstablished;
 
 	mutable boost::mutex m_curStatsMutex;
@@ -258,6 +288,9 @@ friend class ClientStateWaitChooseServer;
 friend class ClientStateStartConnect;
 friend class ClientStateConnecting;
 friend class ClientStateStartSession;
+friend class ClientStateWaitEnterLogin;
+friend class ClientStateWaitAuthChallenge;
+friend class ClientStateWaitAuthVerify;
 friend class ClientStateWaitSession;
 friend class ClientStateWaitJoin;
 friend class ClientStateWaitGame;
