@@ -17,6 +17,10 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include <boost/asio.hpp>
+#include <boost/bind.hpp>
+#include <algorithm>
+
 #include <net/servergame.h>
 #include <net/servergamestate.h>
 #include <net/serverlobbythread.h>
@@ -25,11 +29,13 @@
 #include <net/receiverhelper.h>
 #include <net/socket_msg.h>
 #include <core/loghelper.h>
+#include <db/serverdbinterface.h>
+#include <db/serverdbnoaction.h>
 #include <game.h>
+#include <log.h>
 #include <localenginefactory.h>
 #include <tools.h>
-
-#include <boost/bind.hpp>
+#include <configfile.h>
 
 
 #define SERVER_CHECK_VOTE_KICK_INTERVAL_MSEC	500
@@ -37,11 +43,18 @@
 
 using namespace std;
 
+static bool LessThanPlayerHandStartMoney(const boost::shared_ptr<PlayerInterface> p1, const boost::shared_ptr<PlayerInterface> p2)
+{
+	return p1->getMyRoundStartCash() < p2->getMyRoundStartCash();
+}
 
-ServerGame::ServerGame(boost::shared_ptr<ServerLobbyThread> lobbyThread, u_int32_t id, const string &name, const string &pwd, const GameData &gameData, unsigned adminPlayerId, GuiInterface &gui, ConfigFile *playerConfig)
+
+ServerGame::ServerGame(boost::shared_ptr<ServerLobbyThread> lobbyThread, u_int32_t id, const string &name, const string &pwd, const GameData &gameData, unsigned adminPlayerId, GuiInterface &gui, ConfigFile &playerConfig, Log &serverLog)
 : m_adminPlayerId(adminPlayerId), m_lobbyThread(lobbyThread), m_gui(gui),
-  m_gameData(gameData), m_curState(NULL), m_id(id), m_name(name), m_password(pwd), m_playerConfig(playerConfig),
-  m_gameNum(1), m_curPetitionId(1), m_voteKickTimer(lobbyThread->GetIOService()), m_stateTimer(lobbyThread->GetIOService())
+  m_gameData(gameData), m_curState(NULL), m_id(id), m_dbId(DB_ID_INVALID), m_name(name),
+  m_password(pwd), m_playerConfig(playerConfig), m_serverLog(serverLog), m_gameNum(1),
+  m_curPetitionId(1), m_doNotAutoKickSmallDelaySec(10), m_voteKickTimer(lobbyThread->GetIOService()),
+  m_stateTimer1(lobbyThread->GetIOService()), m_stateTimer2(lobbyThread->GetIOService())
 {
 	LOG_VERBOSE("Game object " << GetId() << " created.");
 
@@ -56,12 +69,7 @@ ServerGame::~ServerGame()
 void
 ServerGame::Init()
 {
-	m_voteKickTimer.expires_from_now(
-		boost::posix_time::milliseconds(SERVER_CHECK_VOTE_KICK_INTERVAL_MSEC));
-	m_voteKickTimer.async_wait(
-		boost::bind(
-			&ServerGame::TimerVoteKick, shared_from_this(), boost::asio::placeholders::error));
-
+	m_doNotAutoKickSmallDelaySec = m_playerConfig.readConfigInt("ServerDoNotAutoKickSmallDelaySec");
 	SetState(SERVER_INITIAL_STATE::Instance());
 }
 
@@ -84,6 +92,18 @@ ServerGame::GetName() const
 	return m_name;
 }
 
+DB_id
+ServerGame::GetDBId() const
+{
+	return m_dbId;
+}
+
+void
+ServerGame::SetDBId(DB_id newId)
+{
+	m_dbId = newId;
+}
+
 void
 ServerGame::AddSession(SessionWrapper session)
 {
@@ -119,12 +139,19 @@ ServerGame::SendToAllPlayers(boost::shared_ptr<NetPacket> packet, SessionData::S
 	GetSessionManager().SendToAllSessions(GetLobbyThread().GetSender(), packet, state);
 }
 
+void
+ServerGame::SendToAllButOnePlayers(boost::shared_ptr<NetPacket> packet, SessionId except, SessionData::State state)
+{
+	GetSessionManager().SendToAllButOneSessions(GetLobbyThread().GetSender(), packet, except, state);
+}
+
 void
 ServerGame::RemoveAllSessions()
 {
-	// Called from lobby thread.
 	// Clean up ALL sessions which are left.
 	GetSessionManager().ForEach(boost::bind(&ServerLobbyThread::RemoveSessionFromGame, boost::ref(*m_lobbyThread), _1));
+	GetSessionManager().Clear();
+	SetState(ServerGameStateFinal::Instance());
 }
 
 void
@@ -180,16 +207,16 @@ ServerGame::TimerVoteKick(const boost::system::error_code &ec)
 			}
 			if (abortPetition)
 			{
-				boost::shared_ptr<NetPacket> endPetition(new NetPacketEndKickPlayerPetition);
-				NetPacketEndKickPlayerPetition::Data endPetitionData;
-				endPetitionData.petitionId = m_voteKickData->petitionId;
-				endPetitionData.numVotesAgainstKicking = m_voteKickData->numVotesAgainstKicking;
-				endPetitionData.numVotesInFavourOfKicking = m_voteKickData->numVotesInFavourOfKicking;
-				endPetitionData.playerKicked = doKick;
-				endPetitionData.endReason = reason;
-
-				static_cast<NetPacketEndKickPlayerPetition *>(endPetition.get())->SetData(endPetitionData);
-				SendToAllPlayers(endPetition, SessionData::Game);
+				boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+				packet->GetMsg()->present = PokerTHMessage_PR_endKickPetitionMessage;
+				EndKickPetitionMessage_t *netEndPetition = &packet->GetMsg()->choice.endKickPetitionMessage;
+				netEndPetition->gameId = GetId();
+				netEndPetition->petitionId = m_voteKickData->petitionId;
+				netEndPetition->numVotesAgainstKicking = m_voteKickData->numVotesAgainstKicking;
+				netEndPetition->numVotesInFavourOfKicking = m_voteKickData->numVotesInFavourOfKicking;
+				netEndPetition->resultPlayerKicked = doKick;
+				netEndPetition->petitionEndReason = reason;
+				SendToAllPlayers(packet, SessionData::Game);
 
 				// Perform kick.
 				if (doKick)
@@ -197,63 +224,170 @@ ServerGame::TimerVoteKick(const boost::system::error_code &ec)
 				// This petition has ended.
 				m_voteKickData.reset();
 			}
+			m_voteKickTimer.expires_from_now(
+				boost::posix_time::milliseconds(SERVER_CHECK_VOTE_KICK_INTERVAL_MSEC));
+			m_voteKickTimer.async_wait(
+				boost::bind(
+					&ServerGame::TimerVoteKick, shared_from_this(), boost::asio::placeholders::error));
 		}
-		m_voteKickTimer.expires_from_now(
-			boost::posix_time::milliseconds(SERVER_CHECK_VOTE_KICK_INTERVAL_MSEC));
-		m_voteKickTimer.async_wait(
-			boost::bind(
-				&ServerGame::TimerVoteKick, shared_from_this(), boost::asio::placeholders::error));
 	}
 }
 
-void
+PlayerDataList
 ServerGame::InternalStartGame()
 {
-	// Set order of players.
-	AssignPlayerNumbers();
-
 	// Initialize the game.
-	GuiInterface &gui = GetGui();
-	PlayerDataList playerData = GetFullPlayerDataList();
+	PlayerDataList playerData(GetFullPlayerDataList());
 
-	// Create EngineFactory
-	boost::shared_ptr<EngineFactory> factory(new LocalEngineFactory(m_playerConfig)); // LocalEngine erstellen
-
-	// Set start data.
-	StartData startData;
-	startData.numberOfPlayers = playerData.size();
-
-	int tmpDealerPos = 0;
-	Tools::getRandNumber(0, startData.numberOfPlayers-1, 1, &tmpDealerPos, 0);
-	// The Player Id is not continuous. Therefore, the start dealer position
-	// needs to be converted to a player Id, and cannot be directly generated
-	// as player Id.
-	PlayerDataList::const_iterator player_i = playerData.begin();
-	PlayerDataList::const_iterator player_end = playerData.end();
-
-	int tmpPos = 0;
-	while (player_i != player_end)
+	if (playerData.size() >= 2)
 	{
-		startData.startDealerPlayerId = static_cast<unsigned>((*player_i)->GetUniqueId());
-		if (tmpPos == tmpDealerPos)
-			break;
-		++tmpPos;
-		++player_i;
+		// Set DB Backend.
+		if (GetGameData().gameType == GAME_TYPE_RANKING)
+			m_database = GetLobbyThread().GetDatabase();
+		else
+			m_database.reset(new ServerDBNoAction);
+
+		// Randomize player list.
+		// Note: This does not use a cryptographically strong
+		// random number generator.
+		vector<boost::shared_ptr<PlayerData> > tmpData(playerData.begin(), playerData.end());
+		random_shuffle(tmpData.begin(), tmpData.end());
+		copy(tmpData.begin(), tmpData.end(), playerData.begin());
+
+		// Set order of players.
+		AssignPlayerNumbers(playerData);
+
+		// Create EngineFactory
+		boost::shared_ptr<EngineFactory> factory(new LocalEngineFactory(&m_playerConfig)); // LocalEngine erstellen
+
+		// Set start data.
+		StartData startData;
+		startData.numberOfPlayers = playerData.size();
+
+		int tmpDealerPos = 0;
+		Tools::getRandNumber(0, startData.numberOfPlayers-1, 1, &tmpDealerPos, 0);
+		// The Player Id is not continuous. Therefore, the start dealer position
+		// needs to be converted to a player Id, and cannot be directly generated
+		// as player Id.
+		PlayerDataList::const_iterator player_i = playerData.begin();
+		PlayerDataList::const_iterator player_end = playerData.end();
+
+		int tmpPos = 0;
+		while (player_i != player_end)
+		{
+			startData.startDealerPlayerId = static_cast<unsigned>((*player_i)->GetUniqueId());
+			if (tmpPos == tmpDealerPos)
+				break;
+			++tmpPos;
+			++player_i;
+		}
+		if (player_i == player_end)
+			throw ServerException(__FILE__, __LINE__, ERR_NET_DEALER_NOT_FOUND, 0);
+
+		SetStartData(startData);
+
+		GuiInterface &gui = GetGui();
+		m_game.reset(new Game(&gui, factory, playerData, GetGameData(), GetStartData(), GetNextGameNum(), &m_serverLog));
+
+		GetDatabase().AsyncCreateGame(GetId(), GetName());
+		InitRankingMap(playerData);
 	}
-	if (player_i == player_end)
-		throw ServerException(__FILE__, __LINE__, ERR_NET_DEALER_NOT_FOUND, 0);
-
-	SetStartData(startData);
-
-	m_game.reset(new Game(&gui, factory, playerData, GetGameData(), GetStartData(), GetNextGameNum()));
-
-	GetLobbyThread().NotifyStartingGame(GetId());
+	return playerData;
 }
 
 void
-ServerGame::ResetGame()
+ServerGame::InitRankingMap(const PlayerDataList &playerDataList)
 {
+	PlayerDataList::const_iterator i = playerDataList.begin();
+	PlayerDataList::const_iterator end = playerDataList.end();
+	while (i != end)
+	{
+		boost::shared_ptr<PlayerData> tmpPlayer(*i);
+		RankingData tmpData(tmpPlayer->GetDBId());
+		m_rankingMap[tmpPlayer->GetUniqueId()] = tmpData;
+		++i;
+	}
+}
+
+void
+ServerGame::UpdateRankingMap()
+{
+	list<boost::shared_ptr<PlayerInterface> > activePlayers = *m_game->getActivePlayerList();
+	int currentRank = static_cast<int>(activePlayers.size());
+	list<boost::shared_ptr<PlayerInterface> > tmpRemovedPlayers;
+	PlayerListIterator active_i = activePlayers.begin();
+	PlayerListIterator active_end = activePlayers.end();
+	PlayerListIterator next_active_i = active_i;
+	while(active_i != active_end)
+	{
+		++next_active_i;
+		if ((*active_i)->getMyCash() < 1)
+		{
+			tmpRemovedPlayers.push_back(*active_i);
+			activePlayers.erase(active_i);
+		}
+		active_i = next_active_i;
+	}
+
+	if (!tmpRemovedPlayers.empty())
+	{
+		tmpRemovedPlayers.sort(LessThanPlayerHandStartMoney);
+		PlayerListConstIterator removed_i = tmpRemovedPlayers.begin();
+		PlayerListConstIterator removed_end = tmpRemovedPlayers.end();
+		PlayerListConstIterator next_removed_i = removed_i;
+		int currentRankCounter = 0;
+		while (removed_i != removed_end)
+		{
+			++next_removed_i;
+
+			SetPlayerPlace((*removed_i)->getMyUniqueID(), currentRank);
+			++currentRankCounter;
+			if (next_removed_i != removed_end && (*removed_i)->getMyRoundStartCash() < (*next_removed_i)->getMyRoundStartCash())
+			{
+				currentRank -= currentRankCounter;
+				currentRankCounter = 0;
+			}
+
+			removed_i = next_removed_i;
+		}
+	}
+	// Last player is winner.
+	if (activePlayers.size() == 1)
+	{
+		SetPlayerPlace((*(activePlayers.begin()))->getMyUniqueID(), 1);
+	}
+}
+
+void
+ServerGame::SetPlayerPlace(unsigned playerId, int place)
+{
+	RankingMap::iterator pos = m_rankingMap.find(playerId);
+	if (pos != m_rankingMap.end())
+	{
+		(*pos).second.place = place;
+	}
+}
+
+void
+ServerGame::InternalEndGame()
+{
+	// Store players in database.
+	if (GetDBId() != DB_ID_INVALID)
+	{
+		RankingMap::const_iterator i = m_rankingMap.begin();
+		RankingMap::const_iterator end = m_rankingMap.end();
+		while (i != end)
+		{
+			if ((*i).second.dbid != DB_ID_INVALID)
+			{
+				GetDatabase().SetGamePlayerPlace(GetDBId(), (*i).second.dbid, (*i).second.place);
+			}
+			++i;
+		}
+	}
+	GetDatabase().EndGame(GetDBId());
 	m_game.reset();
+	m_rankingMap.clear();
 }
 
 void
@@ -279,7 +413,7 @@ ServerGame::InternalAskVoteKick(SessionWrapper byWhom, unsigned playerIdWho, uns
 	if (IsRunning() && byWhom.playerData)
 	{
 		// Retrieve only the number of human players.
-		size_t numPlayers = GetSessionManager().GetPlayerIdList().size();
+		size_t numPlayers = GetSessionManager().GetPlayerIdList(SessionData::Game).size();
 		if (numPlayers > 2)
 		{
 			// Check whether the player to be kicked exists.
@@ -299,16 +433,23 @@ ServerGame::InternalAskVoteKick(SessionWrapper byWhom, unsigned playerIdWho, uns
 					m_voteKickData->numVotesInFavourOfKicking = 1;
 					m_voteKickData->votedPlayerIds.push_back(playerIdByWhom);
 
-					boost::shared_ptr<NetPacket> startPetition(new NetPacketStartKickPlayerPetition);
-					NetPacketStartKickPlayerPetition::Data startPetitionData;
-					startPetitionData.petitionId = m_voteKickData->petitionId;
-					startPetitionData.proposingPlayerId = playerIdByWhom;
-					startPetitionData.kickPlayerId = m_voteKickData->kickPlayerId;
-					startPetitionData.kickTimeoutSec = timeoutSec;
-					startPetitionData.numVotesNeededToKick = m_voteKickData->numVotesToKick;
+					boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+					packet->GetMsg()->present = PokerTHMessage_PR_startKickPetitionMessage;
+					StartKickPetitionMessage_t *netStartPetition = &packet->GetMsg()->choice.startKickPetitionMessage;
+					netStartPetition->gameId = GetId();
+					netStartPetition->petitionId = m_voteKickData->petitionId;
+					netStartPetition->proposingPlayerId = playerIdByWhom;
+					netStartPetition->kickPlayerId = m_voteKickData->kickPlayerId;
+					netStartPetition->kickTimeoutSec = timeoutSec;
+					netStartPetition->numVotesNeededToKick = m_voteKickData->numVotesToKick;
+					SendToAllPlayers(packet, SessionData::Game);
+
+					m_voteKickTimer.expires_from_now(
+						boost::posix_time::milliseconds(SERVER_CHECK_VOTE_KICK_INTERVAL_MSEC));
+					m_voteKickTimer.async_wait(
+						boost::bind(
+							&ServerGame::TimerVoteKick, shared_from_this(), boost::asio::placeholders::error));
 
-					static_cast<NetPacketStartKickPlayerPetition *>(startPetition.get())->SetData(startPetitionData);
-					SendToAllPlayers(startPetition, SessionData::Game);
 				}
 				else
 					InternalDenyAskVoteKick(byWhom, playerIdWho, KICK_DENIED_OTHER_IN_PROGRESS);
@@ -326,12 +467,13 @@ ServerGame::InternalAskVoteKick(SessionWrapper byWhom, unsigned playerIdWho, uns
 void
 ServerGame::InternalDenyAskVoteKick(SessionWrapper byWhom, unsigned playerIdWho, DenyKickPlayerReason reason)
 {
-	boost::shared_ptr<NetPacket> denyPetition(new NetPacketAskKickPlayerDenied);
-	NetPacketAskKickPlayerDenied::Data denyPetitionData;
-	denyPetitionData.playerId = playerIdWho;
-	denyPetitionData.denyReason = reason;
-	static_cast<NetPacketAskKickPlayerDenied *>(denyPetition.get())->SetData(denyPetitionData);
-	GetLobbyThread().GetSender().Send(byWhom.sessionData, denyPetition);
+	boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+	packet->GetMsg()->present = PokerTHMessage_PR_askKickDeniedMessage;
+	AskKickDeniedMessage_t *netKickDenied = &packet->GetMsg()->choice.askKickDeniedMessage;
+	netKickDenied->gameId = GetId();
+	netKickDenied->playerId = playerIdWho;
+	netKickDenied->kickDeniedReason = reason;
+	GetLobbyThread().GetSender().Send(byWhom.sessionData, packet);
 }
 
 void
@@ -352,15 +494,15 @@ ServerGame::InternalVoteKick(SessionWrapper byWhom, unsigned petitionId, KickVot
 				else
 					m_voteKickData->numVotesAgainstKicking++;
 				// Send update notification.
-				boost::shared_ptr<NetPacket> updatePetition(new NetPacketKickPlayerPetitionUpdate);
-				NetPacketKickPlayerPetitionUpdate::Data updatePetitionData;
-				updatePetitionData.petitionId = m_voteKickData->petitionId;
-				updatePetitionData.numVotesAgainstKicking = m_voteKickData->numVotesAgainstKicking;
-				updatePetitionData.numVotesInFavourOfKicking = m_voteKickData->numVotesInFavourOfKicking;
-				updatePetitionData.numVotesNeededToKick = m_voteKickData->numVotesToKick;
-
-				static_cast<NetPacketKickPlayerPetitionUpdate *>(updatePetition.get())->SetData(updatePetitionData);
-				SendToAllPlayers(updatePetition, SessionData::Game);
+				boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+				packet->GetMsg()->present = PokerTHMessage_PR_kickPetitionUpdateMessage;
+				KickPetitionUpdateMessage_t *netKickUpdate = &packet->GetMsg()->choice.kickPetitionUpdateMessage;
+				netKickUpdate->gameId = GetId();
+				netKickUpdate->petitionId = m_voteKickData->petitionId;
+				netKickUpdate->numVotesAgainstKicking = m_voteKickData->numVotesAgainstKicking;
+				netKickUpdate->numVotesInFavourOfKicking = m_voteKickData->numVotesInFavourOfKicking;
+				netKickUpdate->numVotesNeededToKick = m_voteKickData->numVotesToKick;
+				SendToAllPlayers(packet, SessionData::Game);
 			}
 			else
 				InternalDenyVoteKick(byWhom, petitionId, VOTE_DENIED_ALREADY_VOTED);
@@ -369,18 +511,22 @@ ServerGame::InternalVoteKick(SessionWrapper byWhom, unsigned petitionId, KickVot
 			InternalDenyVoteKick(byWhom, petitionId, VOTE_DENIED_INVALID_PETITION);
 	}
 	else
-		InternalDenyVoteKick(byWhom, petitionId, VOTE_DENIED_IMPOSSIBLE);
+		InternalDenyVoteKick(byWhom, petitionId, VOTE_DENIED_INVALID_PETITION);
 }
 
 void
 ServerGame::InternalDenyVoteKick(SessionWrapper byWhom, unsigned petitionId, DenyVoteReason reason)
 {
-	boost::shared_ptr<NetPacket> denyVote(new NetPacketVoteKickPlayerDenied);
-	NetPacketVoteKickPlayerDenied::Data denyVoteData;
-	denyVoteData.petitionId = petitionId;
-	denyVoteData.denyReason = reason;
-	static_cast<NetPacketVoteKickPlayerDenied *>(denyVote.get())->SetData(denyVoteData);
-	GetLobbyThread().GetSender().Send(byWhom.sessionData, denyVote);
+	boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
+	packet->GetMsg()->present = PokerTHMessage_PR_voteKickReplyMessage;
+	VoteKickReplyMessage_t *netVoteReply = &packet->GetMsg()->choice.voteKickReplyMessage;
+	netVoteReply->gameId = GetId();
+	netVoteReply->petitionId = petitionId;
+	netVoteReply->voteKickReplyType.present = voteKickReplyType_PR_voteKickDenied;
+
+	VoteKickDenied_t *kickDenied = &netVoteReply->voteKickReplyType.choice.voteKickDenied;
+	kickDenied->voteKickDeniedReason = reason;
+	GetLobbyThread().GetSender().Send(byWhom.sessionData, packet);
 }
 
 PlayerDataList
@@ -423,7 +569,7 @@ ServerGame::GetPlayerDataByUniqueId(unsigned playerId) const
 PlayerIdList
 ServerGame::GetPlayerIdList() const
 {
-	PlayerIdList idList(GetSessionManager().GetPlayerIdList());
+	PlayerIdList idList(GetSessionManager().GetPlayerIdList(SessionData::Game));
 	boost::mutex::scoped_lock lock(m_computerPlayerListMutex);
 	PlayerDataList::const_iterator i = m_computerPlayerList.begin();
 	PlayerDataList::const_iterator end = m_computerPlayerList.end();
@@ -442,6 +588,18 @@ ServerGame::IsPlayerConnected(const std::string &name) const
 	return GetSessionManager().IsPlayerConnected(name);
 }
 
+bool
+ServerGame::IsPlayerConnected(unsigned playerId) const
+{
+	return GetSessionManager().IsPlayerConnected(playerId);
+}
+
+bool
+ServerGame::IsClientAddressConnected(const std::string &clientAddress) const
+{
+	return GetSessionManager().IsClientAddressConnected(clientAddress);
+}
+
 bool
 ServerGame::IsRunning() const
 {
@@ -460,6 +618,51 @@ ServerGame::SetAdminPlayerId(unsigned playerId)
 	m_adminPlayerId = playerId;
 }
 
+void
+ServerGame::AddPlayerInvitation(unsigned playerId)
+{
+	boost::mutex::scoped_lock lock(m_playerInvitationListMutex);
+	m_playerInvitationList.push_back(playerId);
+	m_playerInvitationList.sort();
+	m_playerInvitationList.unique();
+}
+
+void
+ServerGame::RemovePlayerInvitation(unsigned playerId)
+{
+	boost::mutex::scoped_lock lock(m_playerInvitationListMutex);
+	m_playerInvitationList.remove(playerId);
+}
+
+bool
+ServerGame::IsPlayerInvited(unsigned playerId) const
+{
+	bool retVal = false;
+	boost::mutex::scoped_lock lock(m_playerInvitationListMutex);
+	PlayerIdList::const_iterator pos = find(m_playerInvitationList.begin(), m_playerInvitationList.end(), playerId);
+	if (pos != m_playerInvitationList.end())
+		retVal = true;
+	return retVal;
+}
+
+void
+ServerGame::AddReportedAvatar(unsigned playerId)
+{
+	boost::mutex::scoped_lock lock(m_reportedAvatarListMutex);
+	m_reportedAvatarList.push_back(playerId);
+}
+
+bool
+ServerGame::IsAvatarReported(unsigned playerId) const
+{
+	bool retVal = false;
+	boost::mutex::scoped_lock lock(m_reportedAvatarListMutex);
+	PlayerIdList::const_iterator pos = find(m_reportedAvatarList.begin(), m_reportedAvatarList.end(), playerId);
+	if (pos != m_reportedAvatarList.end())
+		retVal = true;
+	return retVal;
+}
+
 void
 ServerGame::AddComputerPlayer(boost::shared_ptr<PlayerData> player)
 {
@@ -530,21 +733,23 @@ ServerGame::ResetComputerPlayerList()
 void
 ServerGame::GracefulRemoveSession(SessionWrapper session, int reason)
 {
-	if (!session.sessionData.get())
+	if (!session.sessionData)
 		throw ServerException(__FILE__, __LINE__, ERR_NET_INVALID_SESSION, 0);
-	GetSessionManager().RemoveSession(session.sessionData->GetId());
 
-	boost::shared_ptr<PlayerData> tmpPlayerData = session.playerData;
-	if (tmpPlayerData.get() && !tmpPlayerData->GetName().empty())
+	if (GetSessionManager().RemoveSession(session.sessionData->GetId()))
 	{
-		RemovePlayerData(tmpPlayerData, reason);
+		boost::shared_ptr<PlayerData> tmpPlayerData = session.playerData;
+		if (tmpPlayerData && !tmpPlayerData->GetName().empty())
+		{
+			RemovePlayerData(tmpPlayerData, reason);
+		}
 	}
 }
 
 void
 ServerGame::RemovePlayerData(boost::shared_ptr<PlayerData> player, int reason)
 {
-	if (player->GetRights() == PLAYER_RIGHTS_ADMIN)
+	if (player->IsGameAdmin())
 	{
 		// Find new admin for the game
 		PlayerDataList playerList(GetSessionManager().GetPlayerDataList());
@@ -552,30 +757,50 @@ ServerGame::RemovePlayerData(boost::shared_ptr<PlayerData> player, int reason)
 		{
 			boost::shared_ptr<PlayerData> newAdmin = playerList.front();
 			SetAdminPlayerId(newAdmin->GetUniqueId());
-			newAdmin->SetRights(PLAYER_RIGHTS_ADMIN);
+			newAdmin->SetGameAdmin(true);
 			// Notify game state on admin change
 			GetState().NotifyGameAdminChanged(shared_from_this());
 			// Send "Game Admin Changed" to clients.
-			boost::shared_ptr<NetPacket> adminChanged(new NetPacketGameAdminChanged);
-			NetPacketGameAdminChanged::Data adminChangedData;
-			adminChangedData.playerId = newAdmin->GetUniqueId(); // Choose next player as admin.
-			static_cast<NetPacketGameAdminChanged *>(adminChanged.get())->SetData(adminChangedData);
+			boost::shared_ptr<NetPacket> adminChanged(new NetPacket(NetPacket::Alloc));
+			adminChanged->GetMsg()->present = PokerTHMessage_PR_gamePlayerMessage;
+			GamePlayerMessage_t *netGameAdmin = &adminChanged->GetMsg()->choice.gamePlayerMessage;
+			netGameAdmin->gameId = GetId();
+
+			netGameAdmin->gamePlayerNotification.present = gamePlayerNotification_PR_gameAdminChanged;
+			GameAdminChanged_t *gameAdmin = &netGameAdmin->gamePlayerNotification.choice.gameAdminChanged;
+			gameAdmin->newAdminPlayerId = newAdmin->GetUniqueId(); // Choose next player as admin.
 			GetSessionManager().SendToAllSessions(GetLobbyThread().GetSender(), adminChanged, SessionData::Game);
 
 			GetLobbyThread().NotifyGameAdminChanged(GetId(), newAdmin->GetUniqueId());
 		}
 	}
 	// Reset player rights.
-	player->SetRights(PLAYER_RIGHTS_NORMAL);
+	player->SetGameAdmin(false);
 
 	// Send "Player Left" to clients.
-	boost::shared_ptr<NetPacket> thisPlayerLeft(new NetPacketPlayerLeft);
-	NetPacketPlayerLeft::Data thisPlayerLeftData;
-	thisPlayerLeftData.playerId = player->GetUniqueId();
-	thisPlayerLeftData.removeReason = reason;
-	static_cast<NetPacketPlayerLeft *>(thisPlayerLeft.get())->SetData(thisPlayerLeftData);
+	boost::shared_ptr<NetPacket> thisPlayerLeft(new NetPacket(NetPacket::Alloc));
+	thisPlayerLeft->GetMsg()->present = PokerTHMessage_PR_gamePlayerMessage;
+	GamePlayerMessage_t *netPlayerLeft = &thisPlayerLeft->GetMsg()->choice.gamePlayerMessage;
+	netPlayerLeft->gameId = GetId();
+
+	netPlayerLeft->gamePlayerNotification.present = gamePlayerNotification_PR_gamePlayerLeft;
+	GamePlayerLeft_t *gamePlayer = &netPlayerLeft->gamePlayerNotification.choice.gamePlayerLeft;
+	gamePlayer->playerId = player->GetUniqueId();
+	switch (reason)
+	{
+		case NTF_NET_REMOVED_ON_REQUEST :
+			gamePlayer->gamePlayerLeftReason = gamePlayerLeftReason_leftOnRequest;
+			break;
+		case NTF_NET_REMOVED_KICKED :
+			gamePlayer->gamePlayerLeftReason = gamePlayerLeftReason_leftKicked;
+			break;
+		default :
+			gamePlayer->gamePlayerLeftReason = gamePlayerLeftReason_leftError;
+			break;
+	}
 	GetSessionManager().SendToAllSessions(GetLobbyThread().GetSender(), thisPlayerLeft, SessionData::Game);
 
+	GetState().NotifySessionRemoved(shared_from_this());
 	GetLobbyThread().NotifyPlayerLeftGame(GetId(), player->GetUniqueId());
 }
 
@@ -608,7 +833,7 @@ void
 ServerGame::RemoveDisconnectedPlayers()
 {
 	// This should only be called between hands.
-	if (m_game.get())
+	if (m_game)
 	{
 		PlayerListIterator i = m_game->getSeatsList()->begin();
 		PlayerListIterator end = m_game->getSeatsList()->end();
@@ -634,11 +859,10 @@ ServerGame::GetCurNumberOfPlayers() const
 }
 
 void
-ServerGame::AssignPlayerNumbers()
+ServerGame::AssignPlayerNumbers(PlayerDataList &playerList)
 {
 	int playerNumber = 0;
 
-	PlayerDataList playerList = GetFullPlayerDataList();
 	PlayerDataList::iterator player_i = playerList.begin();
 	PlayerDataList::iterator player_end = playerList.end();
 
@@ -672,6 +896,13 @@ ServerGame::GetSessionManager() const
 	return m_sessionManager;
 }
 
+ServerDBInterface &
+ServerGame::GetDatabase()
+{
+	assert(m_database);
+	return *m_database;
+}
+
 ServerLobbyThread &
 ServerGame::GetLobbyThread()
 {
@@ -702,9 +933,15 @@ ServerGame::SetState(ServerGameState &newState)
 }
 
 boost::asio::deadline_timer &
-ServerGame::GetStateTimer()
+ServerGame::GetStateTimer1()
 {
-	return m_stateTimer;
+	return m_stateTimer1;
+}
+
+boost::asio::deadline_timer &
+ServerGame::GetStateTimer2()
+{
+	return m_stateTimer2;
 }
 
 ReceiverHelper &
@@ -714,6 +951,12 @@ ServerGame::GetReceiver()
 	return *m_receiver;
 }
 
+unsigned
+ServerGame::GetSmallDelaySec() const
+{
+	return m_doNotAutoKickSmallDelaySec;
+}
+
 Game &
 ServerGame::GetGame()
 {
@@ -758,6 +1001,26 @@ ServerGame::CheckPassword(const string &password) const
 	return (password == m_password);
 }
 
+bool
+ServerGame::CheckSettings(const GameData &data, const string &password)
+{
+	bool retVal = true;
+	if (data.gameType == GAME_TYPE_RANKING)
+	{
+		if ((data.startMoney != RANKING_GAME_START_CASH)
+			|| (data.maxNumberOfPlayers != RANKING_GAME_NUMBER_OF_PLAYERS)
+			|| (data.firstSmallBlind != RANKING_GAME_START_SBLIND)
+			|| (data.raiseIntervalMode != RAISE_ON_HANDNUMBER)
+			|| (data.raiseMode != DOUBLE_BLINDS)
+			|| (data.raiseSmallBlindEveryHandsValue != RANKING_GAME_RAISE_EVERY_HAND)
+			|| (!password.empty()))
+		{
+			retVal = false;
+		}
+	}
+	return retVal;
+}
+
 GuiInterface &
 ServerGame::GetGui()
 {
