@@ -18,17 +18,21 @@
  ***************************************************************************/
 
 #include <net/sessiondata.h>
+#include <gsasl.h>
+
+using namespace std;
 
 SessionData::SessionData(boost::shared_ptr<boost::asio::ip::tcp::socket> sock, SessionId id, SessionDataCallback &cb)
 : m_socket(sock), m_id(id), m_gameId(0), m_state(SessionData::Init), m_readyFlag(false),
   m_wantsLobbyMsg(true), m_activityTimeoutNoticeSent(false), m_callback(cb),
-  m_maxNumPlayers(0)
+  m_authSession(NULL), m_curAuthStep(0)
 {
 }
 
 SessionData::~SessionData()
 {
 	m_callback.SignalSessionTerminated(m_id);
+	InternalClearAuthSession();
 }
 
 SessionId
@@ -72,6 +76,111 @@ SessionData::GetAsioSocket()
 	return m_socket;
 }
 
+bool
+SessionData::CreateServerAuthSession(Gsasl *context)
+{
+	boost::mutex::scoped_lock lock(m_dataMutex);
+	InternalClearAuthSession();
+	int errorCode;
+	errorCode = gsasl_server_start(context, "SCRAM-SHA-1", &m_authSession);
+	return errorCode == GSASL_OK;
+}
+
+bool
+SessionData::CreateClientAuthSession(Gsasl *context, const string &userName, const string &password)
+{
+	bool retVal = false;
+	boost::mutex::scoped_lock lock(m_dataMutex);
+	InternalClearAuthSession();
+	int errorCode;
+	errorCode = gsasl_client_start(context, "SCRAM-SHA-1", &m_authSession);
+	if (errorCode == GSASL_OK)
+	{
+		gsasl_property_set(m_authSession, GSASL_AUTHID, userName.c_str());
+		gsasl_property_set(m_authSession, GSASL_PASSWORD, password.c_str());
+
+		retVal = true;
+	}
+	return retVal;
+}
+
+bool
+SessionData::AuthStep(int stepNum, const std::string &inData)
+{
+	bool retVal = false;
+	boost::mutex::scoped_lock lock(m_dataMutex);
+	if (m_authSession && stepNum == m_curAuthStep + 1)
+	{
+		m_curAuthStep = stepNum;
+		char *tmpOut;
+		size_t tmpOutSize;
+		int errorCode = gsasl_step(m_authSession, inData.c_str(), inData.length(), &tmpOut, &tmpOutSize);
+		if (errorCode == GSASL_NEEDS_MORE)
+		{
+			m_nextGsaslMsg = string(tmpOut, tmpOutSize);
+			retVal = true;
+		}
+		else if (errorCode == GSASL_OK && stepNum != 1)
+		{
+			m_nextGsaslMsg = string(tmpOut, tmpOutSize);
+			retVal = true;
+			InternalClearAuthSession();
+		}
+		gsasl_free(tmpOut);
+	}
+	return retVal;
+}
+
+string
+SessionData::AuthGetUser() const
+{
+	string retStr;
+	if (m_authSession)
+	{
+		const char *tmpUser = gsasl_property_fast(m_authSession, GSASL_AUTHID);
+		if (tmpUser)
+			retStr = tmpUser;
+	}
+	return retStr;
+}
+
+void
+SessionData::AuthSetPassword(const std::string &password)
+{
+	if (m_authSession)
+		gsasl_property_set(m_authSession, GSASL_PASSWORD, password.c_str());
+	m_password = password;
+}
+
+string
+SessionData::AuthGetPassword() const
+{
+	return m_password;
+}
+
+string
+SessionData::AuthGetNextOutMsg() const
+{
+	return m_nextGsaslMsg;
+}
+
+int
+SessionData::AuthGetCurStepNum() const
+{
+	return m_curAuthStep;
+}
+
+void
+SessionData::InternalClearAuthSession()
+{
+	if (m_authSession)
+	{
+		gsasl_finish(m_authSession);
+		m_authSession = NULL;
+		m_curAuthStep = 0;
+	}
+}
+
 void
 SessionData::SetReadyFlag()
 {
@@ -171,17 +280,3 @@ SessionData::GetAutoDisconnectTimerElapsedSec() const
 	boost::mutex::scoped_lock lock(m_dataMutex);
 	return m_autoDisconnectTimer.elapsed().total_seconds();
 }
-
-unsigned
-SessionData::GetMaxNumPlayers() const
-{
-	boost::mutex::scoped_lock lock(m_dataMutex);
-	return m_maxNumPlayers;
-}
-
-void
-SessionData::SetMaxNumPlayers(unsigned numPlayers)
-{
-	boost::mutex::scoped_lock lock(m_dataMutex);
-	m_maxNumPlayers = numPlayers;
-}
