@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Lothar May                                      *
+ *   Copyright (C) 2007-2009 by Lothar May                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,20 +16,21 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-/* Network server receive thread. */
+/* Network server lobby thread. */
 
-#ifndef _SERVERRECVTHREAD_H_
-#define _SERVERRECVTHREAD_H_
+#ifndef _SERVERLOBBYTHREAD_H_
+#define _SERVERLOBBYTHREAD_H_
 
 #include <boost/asio.hpp>
-#include <deque>
 #include <boost/enable_shared_from_this.hpp>
 
 #include <net/sessionmanager.h>
 #include <net/netpacket.h>
+#include <db/serverdbcallback.h>
 #include <gui/guiinterface.h>
 #include <gamedata.h>
 
+class Log;
 
 #define NET_LOBBY_THREAD_TERMINATE_TIMEOUT_MSEC		20000
 #define NET_ADMIN_IRC_TERMINATE_TIMEOUT_MSEC		4000
@@ -37,22 +38,26 @@
 
 class SenderHelper;
 class ReceiverHelper;
-class ServerSenderCallback;
+class InternalServerCallback;
+class ServerIrcBotCallback;
 class ServerGame;
 class ServerBanManager;
 class ConfigFile;
 class AvatarManager;
+class ChatCleanerManager;
+class ServerDBInterface;
 struct GameData;
 class Game;
+struct Gsasl;
 
 class ServerLobbyThread : public Thread, public boost::enable_shared_from_this<ServerLobbyThread>
 {
 public:
-	ServerLobbyThread(GuiInterface &gui, ConfigFile *playerConfig, AvatarManager &avatarManager,
+	ServerLobbyThread(GuiInterface &gui, ServerMode mode, ServerIrcBotCallback &ircBotCb, ConfigFile &serverConfig, AvatarManager &avatarManager,
 		boost::shared_ptr<boost::asio::io_service> ioService);
 	virtual ~ServerLobbyThread();
 
-	void Init(const std::string &pwd, const std::string &logDir);
+	void Init(const std::string &logDir);
 	virtual void SignalTermination();
 
 	void AddConnection(boost::shared_ptr<boost::asio::ip::tcp::socket> sock);
@@ -61,42 +66,54 @@ public:
 	void RemoveSessionFromGame(SessionWrapper session);
 	void SessionError(SessionWrapper session, int errorCode);
 	void ResubscribeLobbyMsg(SessionWrapper session);
+	void NotifyPlayerJoinedLobby(unsigned playerId);
+	void NotifyPlayerLeftLobby(unsigned playerId);
 	void NotifyPlayerJoinedGame(unsigned gameId, unsigned playerId);
 	void NotifyPlayerLeftGame(unsigned gameId, unsigned playerId);
 	void NotifyGameAdminChanged(unsigned gameId, unsigned newAdminPlayerId);
 	void NotifyStartingGame(unsigned gameId);
 	void NotifyReopeningGame(unsigned gameId);
 
-	void HandleGameRetrievePlayerInfo(SessionWrapper session, const NetPacketRetrievePlayerInfo &tmpPacket);
-	void HandleGameRetrieveAvatar(SessionWrapper session, const NetPacketRetrieveAvatar &tmpPacket);
+	void HandleGameRetrievePlayerInfo(SessionWrapper session, const PlayerInfoRequestMessage_t &playerInfoRequest);
+	void HandleGameRetrieveAvatar(SessionWrapper session, const AvatarRequestMessage_t &retrieveAvatar);
+	void HandleChatRequest(SessionWrapper session, const ChatRequestMessage_t &chatRequest);
 
 	bool KickPlayerByName(const std::string &playerName);
 	std::string GetPlayerIPAddress(const std::string &playerName) const;
+	std::string GetPlayerNameFromId(unsigned playerId) const;
 	void RemovePlayer(unsigned playerId, unsigned errorCode);
 
+
 	void SendGlobalChat(const std::string &message);
 	void SendGlobalMsgBox(const std::string &message);
+	void SendChatBotMsg(const std::string &message);
+	void ReconnectChatBot();
 
 	void AddComputerPlayer(boost::shared_ptr<PlayerData> player);
 	void RemoveComputerPlayer(boost::shared_ptr<PlayerData> player);
 
+	bool SendToLobbyPlayer(unsigned playerId, boost::shared_ptr<NetPacket> packet);
+
 	u_int32_t GetNextUniquePlayerId();
 	u_int32_t GetNextGameId();
 	ServerCallback &GetCallback();
 
+	void SetGameDBId(u_int32_t gameId, DB_id gameDBId);
+
 	AvatarManager &GetAvatarManager();
 
 	ServerStats GetStats() const;
 	boost::posix_time::ptime GetStartTime() const;
+	ServerMode GetServerMode() const;
 
 	SenderHelper &GetSender();
 	boost::asio::io_service &GetIOService();
+	boost::shared_ptr<ServerDBInterface> GetDatabase();
 	ServerBanManager &GetBanManager();
 
 protected:
 
 	typedef std::deque<boost::shared_ptr<boost::asio::ip::tcp::socket> > ConnectQueue;
-	typedef std::deque<SessionWrapper> SessionQueue;
 	typedef std::list<SessionWrapper> SessionList;
 	typedef std::list<SessionId> SessionIdList;
 	typedef std::map<SessionId, boost::timers::portable::microsec_timer> TimerSessionMap;
@@ -108,26 +125,40 @@ protected:
 	virtual void Main();
 	void RegisterTimers();
 	void CancelTimers();
+	void InitAuthContext();
+	void ClearAuthContext();
+	void InitChatCleaner();
 
 	void HandleRead(const boost::system::error_code &ec, SessionId sessionId, size_t bytesRead);
 	void HandlePacket(SessionWrapper session, boost::shared_ptr<NetPacket> packet);
-	void HandleNetPacketInit(SessionWrapper session, const NetPacketInit &tmpPacket);
-	void HandleNetPacketAvatarHeader(SessionWrapper session, const NetPacketAvatarHeader &tmpPacket);
-	void HandleNetPacketUnknownAvatar(SessionWrapper session, const NetPacketUnknownAvatar &tmpPacket);
-	void HandleNetPacketAvatarFile(SessionWrapper session, const NetPacketAvatarFile &tmpPacket);
-	void HandleNetPacketAvatarEnd(SessionWrapper session, const NetPacketAvatarEnd &tmpPacket);
-	void HandleNetPacketRetrievePlayerInfo(SessionWrapper session, const NetPacketRetrievePlayerInfo &tmpPacket);
-	void HandleNetPacketRetrieveAvatar(SessionWrapper session, const NetPacketRetrieveAvatar &tmpPacket);
-	void HandleNetPacketCreateGame(SessionWrapper session, const NetPacketCreateGame &tmpPacket);
-	void HandleNetPacketJoinGame(SessionWrapper session, const NetPacketJoinGame &tmpPacket);
+	void HandleNetPacketInit(SessionWrapper session, const InitMessage_t &initMessage);
+	void HandleNetPacketAuthClientResponse(SessionWrapper session, const AuthClientResponse_t &clientResponse);
+	void HandleNetPacketAvatarHeader(SessionWrapper session, unsigned requestId, const AvatarHeader_t &avatarHeader);
+	void HandleNetPacketUnknownAvatar(SessionWrapper session, unsigned requestId, const UnknownAvatar_t &unknownAvatar);
+	void HandleNetPacketAvatarFile(SessionWrapper session, unsigned requestId, const AvatarData_t &avatarData);
+	void HandleNetPacketAvatarEnd(SessionWrapper session, unsigned requestId, const AvatarEnd_t &avatarEnd);
+	void HandleNetPacketRetrievePlayerInfo(SessionWrapper session, const PlayerInfoRequestMessage_t &playerInfoRequest);
+	void HandleNetPacketRetrieveAvatar(SessionWrapper session, const AvatarRequestMessage_t &retrieveAvatar);
+	void HandleNetPacketCreateGame(SessionWrapper session, const std::string &password, const JoinNewGame_t &newGame);
+	void HandleNetPacketJoinGame(SessionWrapper session, const std::string &password, const JoinExistingGame_t &joinGame);
+	void HandleNetPacketChatRequest(SessionWrapper session, const ChatRequestMessage_t &chatRequest);
+	void HandleNetPacketRejectGameInvitation(SessionWrapper session, const RejectGameInvitationMessage_t &reject);
+	void AuthChallenge(SessionWrapper session, const std::string &secret);
+	void InitAfterLogin(SessionWrapper session);
 	void EstablishSession(SessionWrapper session);
+	void AuthenticatePlayer(SessionWrapper session);
+	void UserValid(unsigned playerId, const DBPlayerData &dbPlayerData);
+	void UserInvalid(unsigned playerId);
+	void UserBlocked(unsigned playerId);
+	void SendReportAvatarResult(unsigned byPlayerId, unsigned reportedPlayerId, bool success);
 	void RequestPlayerAvatar(SessionWrapper session);
 	void TimerRemoveGame(const boost::system::error_code &ec);
 	void TimerRemovePlayer(const boost::system::error_code &ec);
-	void TimerUpdateClientAvatarLock(const boost::system::error_code &ec);
+	void TimerUpdateClientLoginLock(const boost::system::error_code &ec);
 	void TimerCheckSessionTimeouts(const boost::system::error_code &ec);
 	void TimerCleanupAvatarCache(const boost::system::error_code &ec);
 
+	bool IsGameNameInUse(const std::string &gameName) const;
 	boost::shared_ptr<ServerGame> InternalGetGameFromId(unsigned gameId);
 	void InternalAddGame(boost::shared_ptr<ServerGame> game);
 	void InternalRemoveGame(boost::shared_ptr<ServerGame> game);
@@ -142,7 +173,8 @@ protected:
 
 	void CloseSession(SessionWrapper session);
 	void SendError(boost::shared_ptr<SessionData> s, int errorCode);
-	void SendJoinGameFailed(boost::shared_ptr<SessionData> s, int reason);
+	void SendJoinGameFailed(boost::shared_ptr<SessionData> s, unsigned gameId, int reason);
+	void SendPlayerList(boost::shared_ptr<SessionData> s);
 	void SendGameList(boost::shared_ptr<SessionData> s);
 	void UpdateStatisticsNumberOfPlayers();
 	void BroadcastStatisticsUpdate(const ServerStats &stats);
@@ -152,13 +184,14 @@ protected:
 
 	ReceiverHelper &GetReceiver();
 
-	bool CheckPassword(const std::string &password) const;
-
-	ServerSenderCallback &GetSenderCallback();
+	InternalServerCallback &GetSenderCallback();
 	GuiInterface &GetGui();
+	ServerIrcBotCallback &GetIrcBotCallback();
 
 	bool IsPlayerConnected(const std::string &name) const;
 
+	static boost::shared_ptr<NetPacket> CreateNetPacketPlayerListNew(unsigned playerId);
+	static boost::shared_ptr<NetPacket> CreateNetPacketPlayerListLeft(unsigned playerId);
 	static boost::shared_ptr<NetPacket> CreateNetPacketGameListNew(const ServerGame &game);
 	static boost::shared_ptr<NetPacket> CreateNetPacketGameListUpdate(unsigned gameId, GameMode mode);
 
@@ -166,15 +199,17 @@ private:
 
 	boost::shared_ptr<boost::asio::io_service> m_ioService;
 
-	boost::shared_ptr<ServerSenderCallback> m_senderCallback;
+	boost::shared_ptr<InternalServerCallback> m_internalServerCallback;
 	boost::shared_ptr<SenderHelper> m_sender;
 	boost::shared_ptr<ReceiverHelper> m_receiver;
 
 	SessionManager m_sessionManager;
 	SessionManager m_gameSessionManager;
 
-	TimerClientAddressMap m_timerAvatarClientAddressMap;
-	mutable boost::mutex m_timerAvatarClientAddressMapMutex;
+	Gsasl *m_authContext;
+
+	TimerClientAddressMap m_timerClientAddressMap;
+	mutable boost::mutex m_timerClientAddressMapMutex;
 
 	RemoveGameList m_removeGameList;
 	mutable boost::mutex m_removeGameListMutex;
@@ -188,31 +223,38 @@ private:
 	GameMap m_gameMap;
 
 	GuiInterface &m_gui;
+	ServerIrcBotCallback &m_ircBotCb;
 	AvatarManager &m_avatarManager;
 
-	std::string m_password;
+	const ServerMode m_mode;
 	std::string m_statisticsFileName;
-	ConfigFile *m_playerConfig;
+	ConfigFile &m_serverConfig;
 	u_int32_t m_curGameId;
 
 	u_int32_t m_curUniquePlayerId;
 	u_int32_t m_curSessionId;
 	mutable boost::mutex m_curUniquePlayerIdMutex;
 
+	boost::shared_ptr<Log> m_serverLog;
+
 	ServerStats m_statData;
 	bool m_statDataChanged;
 	mutable boost::mutex m_statMutex;
 
 	boost::shared_ptr<ServerBanManager> m_banManager;
+	boost::shared_ptr<ChatCleanerManager> m_chatCleanerManager;
+	boost::shared_ptr<ServerDBInterface> m_database;
 
 	boost::asio::deadline_timer m_removeGameTimer;
 	boost::asio::deadline_timer m_removePlayerTimer;
 	boost::asio::deadline_timer m_sessionTimeoutTimer;
 	boost::asio::deadline_timer m_avatarCleanupTimer;
 	boost::asio::deadline_timer m_saveStatisticsTimer;
-	boost::asio::deadline_timer m_avatarLockTimer;
+	boost::asio::deadline_timer m_loginLockTimer;
 
 	const boost::posix_time::ptime m_startTime;
+
+friend class InternalServerCallback;
 };
 
 #endif
